@@ -12,7 +12,7 @@ class UUIDField(Field):
     UUID valued field, as either a string or UUID object.
 
     """
-    def _serialize(self, value, attr, obj):
+    def _serialize(self, value, attr, obj, **kwargs):
         """
         Serialize value as a uuid, either as a string or an UUID object.
         """
@@ -24,7 +24,7 @@ class UUIDField(Field):
         else:
             return value
 
-    def _deserialize(self, value, attr, data):
+    def _deserialize(self, value, attr, data, **kwargs):
         """
         Deserialize value as a uuid.
 
